==> Req_http_vpn-4.0.0.tar.gz: Req_http_vpn-4.0.0/README.md <==
 ____                       _      _    _
|  _ \   ___   __ _        | |__  | |_ | |_  _ __         __   __ _ __   _ __  
| |_) | / _ \ / _` |       | '_ \ | __|| __|| '_ \        \ \ / /| '_ \ | '_ \ 
|  _ < |  __/| (_| |       | | | || |_ | |_ | |_) |        \ V / | |_) || | | |
|_| \_\ \___| \__, | _____ |_| |_| \__| \__|| .__/  _____   \_/  | .__/ |_| |_|
                 |_||_____|                 |_|    |_____|       |_|
                 
Req_http_vpn Library
~~~~~~~~~~~~~~~~~~~~~

Req_http_vpn Library is an HTTP library, written in Python, for human beings.
Basic GET usage:

>>>   from Req_http_vpn import *
>>>   from os import environ
>>>   environ['print_access_request_library_Req_http_vpn'] = '0'
>>>   this = Requests_filter('https://instagram.com')
>>>   this = this.filter_req_GET()
>>>   print(this.get('status_code'))
   
:Library used in the code: Requests
:Copyright: (c) 2023 Amin Rngbr.
:license: MIT

    ## Requests_filter Class
    The Req_http_vpn library is a simple library for sending **http** requests to websites that are **filtered and blocked** by governments.
    ### How to create an object from this class:
    ```python
    from Req_http_vpn import *
    Req = Requests_filter('https://google.com')
    ```
    And this class has **three functions** >>>
    ```python
    filter_req_GET() #To send http request with GET method
    filter_req_POST() #To send http request with POST method
    filter_req_HEAD() #To send an http request to get website headers
    ```
    `The author and developer of this light and simple library:` َ**Amin Rngbr**
    **and over (:**
    
    **GitHub address**: [aminrngbr1122](https://github.com/aminrngbr1122)

==> Req_http_vpn-4.5.0.tar.gz: Req_http_vpn-4.5.0/README.md <==
 ____                       _      _    _
|  _ \   ___   __ _        | |__  | |_ | |_  _ __         __   __ _ __   _ __  
| |_) | / _ \ / _` |       | '_ \ | __|| __|| '_ \        \ \ / /| '_ \ | '_ \ 
|  _ < |  __/| (_| |       | | | || |_ | |_ | |_) |        \ V / | |_) || | | |
|_| \_\ \___| \__, | _____ |_| |_| \__| \__|| .__/  _____   \_/  | .__/ |_| |_|
                 |_||_____|                 |_|    |_____|       |_|
                 
Req_http_vpn Library
~~~~~~~~~~~~~~~~~~~~~

Req_http_vpn Library is an HTTP library, written in Python, for human beings.
Basic GET usage:

>>>   from Req_http_vpn import *
>>>   from os import environ
>>>   environ['print_access_request_library_Req_http_vpn'] = '0'
>>>   this = Requests_filter('https://instagram.com')
>>>   this = this.filter_req_GET()
>>>   print(this.status_code)
   
:Library used in the code: Requests
:Copyright: (c) 2023 Amin Rngbr.
:license: MIT

    ## Requests_filter Class
    The Req_http_vpn library is a simple library for sending **http** requests to websites that are **filtered and blocked** by governments.
    ### How to create an object from this class:
    ```python
    from Req_http_vpn import *
    Req = Requests_filter('https://google.com')
    ```
    And this class has **three functions** >>>
    ```python
    filter_req_GET() #To send http request with GET method
    filter_req_POST() #To send http request with POST method
    filter_req_HEAD() #To send an http request to get website headers
    ```
    `The author and developer of this light and simple library:` َ**Amin Rngbr**
    **and over (:**
    
    **GitHub address**: [aminrngbr1122](https://github.com/aminrngbr1122)
